@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     Pygments HTML formatter tests
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -7,7 +6,6 @@
     :license: BSD, see LICENSE for details.
 """
 
-import io
 import os
 import re
 import tempfile
@@ -24,7 +22,7 @@ from pygments.style import Style
 TESTDIR = path.dirname(path.abspath(__file__))
 TESTFILE = path.join(TESTDIR, 'test_html_formatter.py')
 
-with io.open(TESTFILE, encoding='utf-8') as fp:
+with open(TESTFILE, encoding='utf-8') as fp:
     tokensource = list(PythonLexer().get_tokens(fp.read()))
 
 
@@ -54,7 +52,7 @@ def test_external_css():
     try:
         fmt2.format(tokensource, tfile)
         assert path.isfile(path.join(TESTDIR, 'fmt2.css'))
-    except IOError:
+    except OSError:
         # test directory not writable
         pass
     tfile.close()
@@ -149,12 +147,12 @@ def test_get_style_defs_contains_default_line_numbers_styles():
     style_defs = HtmlFormatter().get_style_defs().splitlines()
 
     assert style_defs[1] == (
-        'td.linenos pre '
-        '{ color: #000000; background-color: #f0f0f0; padding-left: 5px; padding-right: 5px; }'
+        'td.linenos .normal '
+        '{ color: inherit; background-color: transparent; padding-left: 5px; padding-right: 5px; }'
     )
     assert style_defs[2] == (
         'span.linenos '
-        '{ color: #000000; background-color: #f0f0f0; padding-left: 5px; padding-right: 5px; }'
+        '{ color: inherit; background-color: transparent; padding-left: 5px; padding-right: 5px; }'
     )
 
 
@@ -168,7 +166,7 @@ def test_get_style_defs_contains_style_specific_line_numbers_styles():
     style_defs = HtmlFormatter(style=TestStyle).get_style_defs().splitlines()
 
     assert style_defs[1] == (
-        'td.linenos pre '
+        'td.linenos .normal '
         '{ color: #ff0000; background-color: #0000ff; padding-left: 5px; padding-right: 5px; }'
     )
     assert style_defs[2] == (
@@ -176,7 +174,7 @@ def test_get_style_defs_contains_style_specific_line_numbers_styles():
         '{ color: #ff0000; background-color: #0000ff; padding-left: 5px; padding-right: 5px; }'
     )
     assert style_defs[3] == (
-        'td.linenos pre.special '
+        'td.linenos .special '
         '{ color: #00ff00; background-color: #ffffff; padding-left: 5px; padding-right: 5px; }'
     )
     assert style_defs[4] == (
